@@ -1,6 +1,7 @@
 import asyncio
 import os
 import shutil
+import signal
 import subprocess
 import sys
 import tempfile
@@ -60,7 +61,7 @@ class Hapless(object):
         if verbose:
             table.add_column("Command")
         table.add_column("Status")
-        table.add_column("RC")
+        table.add_column("RC", justify="right")
         table.add_column("Runtime", justify="right")
 
         active_haps = 0
@@ -101,12 +102,16 @@ class Hapless(object):
         cmd_text = Text(f"{hap.cmd}", style=f"{config.COLOR_ACCENT} bold")
         status_table.add_row("Command:", cmd_text)
 
+        proc = hap.proc
+        if verbose and proc is not None:
+            status_table.add_row("Working dir:", f"{proc.cwd()}")
+            status_table.add_row("Parent PID:", f"{proc.ppid()}")
+            status_table.add_row("User:", f"{proc.username()}")
+
         if verbose:
             status_table.add_row("Stdout file:", f"{hap.stdout_path}")
             status_table.add_row("Stderr file:", f"{hap.stderr_path}")
 
-        status_table.add_row("Runtime:", f"{hap.runtime}")
-
         start_time = hap.start_time
         end_time = hap.end_time
         if verbose and start_time:
@@ -115,6 +120,8 @@ class Hapless(object):
         if verbose and end_time:
             status_table.add_row("End time:", f"{end_time}")
 
+        status_table.add_row("Runtime:", f"{hap.runtime}")
+
         status_panel = Panel(
             status_table,
             expand=verbose,
@@ -283,3 +290,35 @@ class Hapless(object):
                 f"{config.ICON_INFO} Nothing to clean",
                 style=f"{config.COLOR_ERROR} bold",
             )
+
+    def kill(self, haps: List[Hap]):
+        killed_counter = 0
+        for hap in haps:
+            if hap.active:
+                logger.info(f"Killing {hap}...")
+                hap.proc.kill()
+                killed_counter += 1
+
+        if killed_counter:
+            console.print(
+                f"{config.ICON_KILLED} Killed {killed_counter} active haps",
+                style=f"{config.COLOR_MAIN} bold",
+            )
+        else:
+            console.print(
+                f"{config.ICON_INFO} No active haps to kill",
+                style=f"{config.COLOR_ERROR} bold",
+            )
+
+    def signal(self, hap: Hap, sig: signal.Signals):
+        if hap.active:
+            sig_text = (
+                f"[bold]{sig.name}[/] ([{config.COLOR_MAIN}]{signal.strsignal(sig)}[/])"
+            )
+            console.print(f"{config.ICON_INFO} Sending {sig_text} to hap {hap}")
+            hap.proc.send_signal(sig)
+        else:
+            console.print(
+                f"{config.ICON_INFO} Cannot send signal to the inactive hap",
+                style=f"{config.COLOR_ERROR} bold",
+            )
